@@ -32,10 +32,9 @@ class MeCab(object):
             # parse a string
             print(nm.parse('この星の一等賞になりたいの卓球で俺は、そんだけ！'))
 
-            # parse string into MeCab nodes,
+            # parse text into Python Generator yielding MeCab nodes,
             # and display much more detailed information about each morpheme
-            nodes = nm.parse('飛べねえ鳥もいるってこった。', as_nodes=True)
-            for n in nodes:
+            for n in nm.parse('飛べねえ鳥もいるってこった。', as_nodes=True):
                 if n.is_nor():
                     print("{}\t{}\t{}".format(n.surface, n.posid, n.wcost))
     '''
@@ -372,7 +371,7 @@ class MeCab(object):
             using either the default or N-best behavior.
         '''
         def _fn(text):
-            '''Parse text and return MeCab result as string.'''
+            '''Parse text and return MeCab result as a string.'''
             args = [self.pointer]
             if fn_name == self._FN_NBEST_TOSTR:
                 args.append(self.options['nbest'])
@@ -395,12 +394,11 @@ class MeCab(object):
                 behavior, either 'mecab_sparse_tonode' or 'mecab_nbest_init'.
 
         Returns:
-            A function definition, tailored to parsing as nodes, using either
-            the default or N-best behavior.
+            A function which returns a Generator, tailored to parsing as nodes,
+            using either the default or N-best behavior.
         '''
         def _fn(text):
             '''Parse text and return MeCab result as a node.'''
-
             if fn_name == self._FN_NBEST_TONODE:
                 # N-best node parsing
                 getattr(self.__mecab, fn_name)(self.pointer, text)
@@ -411,11 +409,10 @@ class MeCab(object):
                 nptr = getattr(self.__mecab, fn_name)(self.pointer, text)
                 count = 1
 
-            nodes = []
             if nptr != self.__ffi.NULL:
                 for _ in range(count):
                     while nptr != self.__ffi.NULL:
-                        # ignore any BOS nodes?
+                        # skip over any BOS nodes, since mecab does
                         if nptr.stat != MeCabNode.BOS_NODE:
                             raws = self.__ffi.string(
                                 nptr.surface[0:nptr.length])
@@ -430,13 +427,12 @@ class MeCab(object):
                             feat = self.__bytes2str(rawf).strip()
 
                             mnode = MeCabNode(nptr, surf, feat)
-                            nodes.append(mnode)
+                            yield(mnode)
                         nptr = getattr(nptr, 'next')
 
                     if fn_name == self._FN_NBEST_TONODE:
                         nptr = self.__mecab.mecab_nbest_next_tonode(
                             self.pointer)
-                return nodes
             else:
                 err = self.__mecab.mecab_strerror((self.pointer))
                 raise MeCabError(self.__bytes2str(self.__ffi.string(err)))
@@ -456,10 +452,14 @@ class MeCab(object):
         '''Parses the given text.
 
         Args:
-            text: the Unicode text to parse.
+            text: the text to parse.
             as_nodes: flag indicating whether to parse as nodes or strings;
                 defaults to False (string parsing).
 
+       Returns:
+            A single string containing the entire MeCab output;
+            or a Generator yielding the MeCab nodes.
+
         Raises:
             MeCabError: a null argument was passed in;
                         or an unforseen error occurred during the operation.
